==> haskell-shelly-1.8.1-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.8.1
id: shelly-1.8.1-N3S48dGHxf7iOntNaQOnE
key: shelly-1.8.1-N3S48dGHxf7iOntNaQOnE
license: BSD-3-Clause
maintainer: Greg Weber <greg@gregweber.info>
author: Greg Weber, Petr Rockai
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
abi: 8a1951dca71d8e38c6c37f6c841f6a80
exposed: True
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find Shelly.Directory
import-dirs: /usr/lib/ghc-8.6.5/site-local/shelly-1.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/shelly-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/shelly-1.8.1
hs-libraries: HSshelly-1.8.1-N3S48dGHxf7iOntNaQOnE
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    enclosed-exceptions-1.0.3-AgElorknxdJGTx8J18nvsL
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    lifted-async-0.10.0.4-3pBM9jNFjmNHLheVP2ty89
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    process-1.6.5.0 system-fileio-0.3.16.4-GhAdzsexM3p6yEXFToM1wE
    system-filepath-0.4.14-GW1RjgWxWC0AXLwQ3KWQjU text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL unix-2.7.2.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.8.1-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.8.1
id: shelly-1.8.1-6zqEFZWvSVYKg0nJbJcYox
key: shelly-1.8.1-6zqEFZWvSVYKg0nJbJcYox
license: BSD-3-Clause
maintainer: Greg Weber <greg@gregweber.info>
author: Greg Weber, Petr Rockai
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
abi: fd2b7458146821903767932ac4407a15
exposed: True
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find Shelly.Directory
import-dirs: /usr/lib/ghc-8.6.5/site-local/shelly-1.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/shelly-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/shelly-1.8.1
hs-libraries: HSshelly-1.8.1-6zqEFZWvSVYKg0nJbJcYox
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    enclosed-exceptions-1.0.3-AgElorknxdJGTx8J18nvsL
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    lifted-async-0.10.0.4-Ca5EALnJ7enGTd0nw9JhDu
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    process-1.6.5.0 system-fileio-0.3.16.4-GhAdzsexM3p6yEXFToM1wE
    system-filepath-0.4.14-GW1RjgWxWC0AXLwQ3KWQjU text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL unix-2.7.2.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
